@@ -1,10 +1,10 @@
-/* 
+/*
     This file is part of Rocs.
     Copyright 2011  Tomaz Canabrava <tomaz.canabrava@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of 
+    published by the Free Software Foundation; either version 2 of
     the License, or (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -24,9 +24,10 @@
 
 class Data;
 
-class NodeItem : public DataItem{
-  Q_OBJECT
-  public:
+class NodeItem : public DataItem
+{
+    Q_OBJECT
+public:
     NodeItem(DataPtr n);
     virtual ~NodeItem();
 };
